##  Leaving a Relation Empty
A relation can intentionally be left blank by selecting Leave Empty. This indicates that no relevant information is mistakenly missing from that field. The relation is treated as filled for calculating the fact sheet completion score, and you can use 'Leave Empty' as a filter criterion in the inventory.
![Leaving a Relation Empty](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274ad6187a4410149164dfc7e8aa6fab_LowRes.png)
Leaving a Relation Empty
